@@ -3,7 +3,7 @@
  * Authors :
  *  Ebby Wiselyn <ebbyw@gnome.org>
  *
- * Copyright 2007, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -31,15 +31,12 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include <bonobo/bonobo-exception.h>
-#include <bonobo/bonobo-moniker-util.h>
-
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
 #include <libedataserver/e-data-server-util.h>
 #include <libedataserver/e-xml-hash-utils.h>
-
+#include <libedataserver/e-proxy.h>
 
 #include <libedata-cal/e-cal-backend-util.h>
 #include <libedata-cal/e-cal-backend-sexp.h>
@@ -72,20 +69,21 @@ struct _ECalBackendGooglePrivate {
 	CalMode	mode;
 	EGoItem *item;
 
-	gint timeout_id;
+	guint timeout_id;
 	gchar *username;
 	gchar *password;
 	gchar *uri;
 	gchar *feed;
-	gchar *local_attachments_store;	
+	gchar *local_attachments_store;
 
 	gboolean read_only;
 	gboolean mode_changed;
 
+	EProxy *proxy;
 };
 
 gint compare_ids (gconstpointer cache_id, gconstpointer modified_cache_id);
-gchar * form_query (const char *query);
+gchar * form_query (const gchar *query);
 
 gint
 compare_ids (gconstpointer cache_id, gconstpointer modified_cache_id)
@@ -96,7 +94,7 @@ compare_ids (gconstpointer cache_id, gconstpointer modified_cache_id)
 /************************************************** Calendar Backend Methods **********************************/
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_attachment_list (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *rid, GSList **list)
+e_cal_backend_google_get_attachment_list (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *rid, GSList **list)
 {
 	/* TODO implement this function */
 	return GNOME_Evolution_Calendar_Success;
@@ -110,7 +108,7 @@ e_cal_backend_google_internal_get_default_timezone (ECalBackend *backend)
 }
 
 static icaltimezone *
-e_cal_backend_google_internal_get_timezone (ECalBackend *backend, const char *tzid)
+e_cal_backend_google_internal_get_timezone (ECalBackend *backend, const gchar *tzid)
 {
 	icaltimezone *zone;
 
@@ -138,7 +136,6 @@ e_cal_backend_google_get_free_busy (ECalBackendSync *backend,
 	return GNOME_Evolution_Calendar_Success;
 }
 
-
 static ECalBackendSyncStatus
 e_cal_backend_google_remove (ECalBackendSync *backend, EDataCal *cal)
 {
@@ -160,7 +157,6 @@ e_cal_backend_google_remove (ECalBackendSync *backend, EDataCal *cal)
 	return GNOME_Evolution_Calendar_Success;
 }
 
-
 static gboolean
 e_cal_backend_google_is_loaded (ECalBackend *backend)
 {
@@ -173,9 +169,8 @@ e_cal_backend_google_is_loaded (ECalBackend *backend)
 	return priv->cache ? TRUE : FALSE;
 }
 
-
 static ECalBackendSyncStatus
-e_cal_backend_google_add_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_google_add_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -207,7 +202,7 @@ e_cal_backend_google_add_timezone (ECalBackendSync *backend, EDataCal *cal, cons
 }
 
 static ECalBackendSyncStatus
- e_cal_backend_google_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *auid)
+ e_cal_backend_google_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *auid)
 {
 	return GNOME_Evolution_Calendar_OtherError;
 }
@@ -225,7 +220,7 @@ e_cal_backend_google_get_mode (ECalBackend *backend)
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzid, char **object)
+e_cal_backend_google_get_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzid, gchar **object)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -250,13 +245,13 @@ e_cal_backend_google_get_timezone (ECalBackendSync *backend, EDataCal *cal, cons
 	if (!icalcomp)
 		return GNOME_Evolution_Calendar_InvalidObject;
 
-	*object = icalcomponent_as_ical_string (icalcomp);
+	*object = icalcomponent_as_ical_string_r (icalcomp);
 
 	return GNOME_Evolution_Calendar_Success;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_object (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *rid, char **object)
+e_cal_backend_google_get_object (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *rid, gchar **object)
 {
 	ECalComponent *comp;
 	ECalBackendGooglePrivate *priv;
@@ -291,7 +286,7 @@ e_cal_backend_google_get_object (ECalBackendSync *backend, EDataCal *cal, const
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_object_list (ECalBackendSync *backend, EDataCal *cal, const char *sexp, GList **objects)
+e_cal_backend_google_get_object_list (ECalBackendSync *backend, EDataCal *cal, const gchar *sexp, GList **objects)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -303,7 +298,9 @@ e_cal_backend_google_get_object_list (ECalBackendSync *backend, EDataCal *cal, c
 	priv = cbgo->priv;
 
 	g_mutex_lock (priv->mutex);
-	search_needed = FALSE;
+
+	if (sexp && g_str_equal (sexp, "#t"))
+		search_needed = FALSE;
 
 	cbsexp = e_cal_backend_sexp_new (sexp);
 
@@ -363,14 +360,14 @@ e_cal_backend_google_start_query (ECalBackend *backend, EDataCalView *query)
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_default_object (ECalBackendSync *backend, EDataCal *cal, char **object)
+e_cal_backend_google_get_default_object (ECalBackendSync *backend, EDataCal *cal, gchar **object)
 {
 	ECalComponent *comp;
 
         comp = e_cal_component_new ();
 	switch (e_cal_backend_get_kind (E_CAL_BACKEND (backend))) {
 	case ICAL_VEVENT_COMPONENT:
-        	e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
+		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
 		break;
 	case ICAL_VTODO_COMPONENT:
 		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_TODO);
@@ -388,7 +385,7 @@ e_cal_backend_google_get_default_object (ECalBackendSync *backend, EDataCal *cal
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_google_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
 {
 	icalcomponent *tz_comp;
 	ECalBackendGoogle *cbgo;
@@ -415,7 +412,6 @@ e_cal_backend_google_set_default_zone (ECalBackendSync *backend, EDataCal *cal,
 	return GNOME_Evolution_Calendar_Success;
 }
 
-
 static void
 e_cal_backend_google_set_mode (ECalBackend *backend, CalMode mode)
 {
@@ -427,7 +423,7 @@ e_cal_backend_google_set_mode (ECalBackend *backend, CalMode mode)
 
 	if (!priv->mode && priv->mode == mode) {
 		e_cal_backend_notify_mode (backend, GNOME_Evolution_Calendar_CalListener_MODE_SET,
-				  	   cal_mode_to_corba (mode));
+					   cal_mode_to_corba (mode));
 		return;
 	}
 
@@ -475,41 +471,41 @@ in_offline (ECalBackendGoogle *cbgo)
 	/* Remove the Connection Object */
 	if (priv->service) {
 		g_object_unref (priv->service);
-		priv->service = NULL;	
+		priv->service = NULL;
 	}
 }
 
 static void
-fetch_attachments (ECalBackendGoogle *cbgo, ECalComponent *comp) 
+fetch_attachments (ECalBackendGoogle *cbgo, ECalComponent *comp)
 {
 	GSList *attach_list = NULL, *new_attach_list = NULL;
 	GSList *l = NULL;
-	const char *uid;	
+	const gchar *uid;
 	gchar *attach_store, *dest_file, *dest_url;
-	int fd;	
+	gint fd;
 
 	e_cal_component_get_attachment_list (comp, &attach_list);
 	e_cal_component_get_uid (comp, &uid);
-	
+
 	attach_store = g_strdup(e_cal_backend_google_get_local_attachments_store (cbgo));
 
-	for (l = attach_list; l; l = l->next) {	
-		char *sfname = (char *)l->data;
-		char *filename, *new_filename;
+	for (l = attach_list; l; l = l->next) {
+		gchar *sfname = (gchar *)l->data;
+		gchar *filename, *new_filename;
 		GMappedFile *mapped_file;
 		GError *error = NULL;
-	
+
 		mapped_file = g_mapped_file_new (sfname, FALSE, &error);
-		if (!mapped_file) {	
-			g_message ("DEBUG: could not map %s: %s \n", 
+		if (!mapped_file) {
+			g_message ("DEBUG: could not map %s: %s \n",
 			sfname, error->message);
 			g_error_free (error);
 			continue;
 		}
-	
+
 		filename = g_path_get_basename (sfname);
 		new_filename = g_strconcat (uid, "-", filename, NULL);
-		g_free (filename);	
+		g_free (filename);
 		dest_file = g_build_filename (attach_store, new_filename, NULL);
 		g_free (new_filename);
 		fd = g_open (dest_file, O_RDWR|O_CREAT|O_TRUNC|O_BINARY, 0600);
@@ -522,19 +518,23 @@ fetch_attachments (ECalBackendGoogle *cbgo, ECalComponent *comp)
 			g_message ("DEBUG: attachment write failed.\n");
 		}
 
+#if GLIB_CHECK_VERSION(2,21,3)
+		g_mapped_file_unref (mapped_file);
+#else
 		g_mapped_file_free (mapped_file);
+#endif
 		if (fd != -1)
-			close (fd);	
+			close (fd);
 		dest_url = g_filename_to_uri (dest_file, NULL, NULL);
 		g_free (dest_url);
-		new_attach_list = g_slist_append (new_attach_list, dest_url);	 
-	}	
+		new_attach_list = g_slist_append (new_attach_list, dest_url);
+	}
 	g_free (attach_store);
 	e_cal_component_set_attachment_list (comp, new_attach_list);
-}	
+}
 
-ECalBackendSyncStatus 
-static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp)
+static ECalBackendSyncStatus
+receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp)
 {
 	ECalBackendGooglePrivate *priv;
 	EGoItem *item = NULL;
@@ -543,59 +543,60 @@ static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *ic
 	GSList *comps = NULL, *l = NULL;
 	icalproperty_method method;
 	icalproperty *icalprop;
-	gboolean instances = TRUE, found = FALSE;
-	icalparameter_partstat pstatus = 0;
+	gboolean instances = TRUE, found = FALSE, is_declined;
 
 	priv = cbgo->priv;
-	icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);	
+	icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
 	while (icalprop) {
-		const char *x_name;
+		const gchar *x_name;
 		x_name	= icalproperty_get_x_name (icalprop);
-		
-		/* FIXME Set the Property for Google */	
+
+		/* FIXME Set the Property for Google */
 		if (!strcmp (x_name, "X-GW-RECUR-INSTANCES-MOD-TYPE")) {
-			instances = TRUE;	
-			icalcomponent_remove_property (icalcomp, icalprop);	
+			instances = TRUE;
+			icalcomponent_remove_property (icalcomp, icalprop);
 			break;
 		}
 		icalprop = icalcomponent_get_next_property (icalcomp, ICAL_X_PROPERTY);
 	}
-	
+
+	is_declined = e_cal_backend_user_declined (icalcomp);
+
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));
-	method = icalcomponent_get_method (icalcomp);	
+	method = icalcomponent_get_method (icalcomp);
 
 	/* Attachments */
-	if (e_cal_component_has_attachments (comp)) 
+	if (!is_declined && e_cal_component_has_attachments (comp))
 		fetch_attachments (cbgo, comp);
-	 
+
 	/* Sent to Server */
-	item = e_go_item_from_cal_component (cbgo, comp);	
+	item = e_go_item_from_cal_component (cbgo, comp);
 	entry =	e_go_item_get_entry (item);
 
 	if (!GDATA_IS_ENTRY(entry))
-		return GNOME_Evolution_Calendar_InvalidObject;	
+		return GNOME_Evolution_Calendar_InvalidObject;
 
 	updated_entry = gdata_service_insert_entry (GDATA_SERVICE(priv->service), priv->uri, entry, NULL);
 
 	if (updated_entry) {
 		/* FIXME */
-		g_object_unref (updated_entry);	
+		g_object_unref (updated_entry);
 	}
 
 	/* Update the Cache */
 
 	modif_comp = g_object_ref (comp);
 	if (instances) {
-		const char *uid;
-		found = FALSE;	
+		const gchar *uid;
+		found = FALSE;
 
 		e_cal_component_get_uid (modif_comp, &uid);
 		comps = e_cal_backend_cache_get_components_by_uid (priv->cache, uid);
 
-		if (!comps) 	
+		if (!comps)
 			comps = g_slist_append (comps, g_object_ref (modif_comp));
-		else	
+		else
 			found = TRUE;
 	} else {
 		ECalComponentId *id = e_cal_component_get_id (modif_comp);
@@ -610,13 +611,13 @@ static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *ic
 			found = TRUE;
 		}
 
-		e_cal_component_free_id (id);	
+		e_cal_component_free_id (id);
 	}
 
 	for (l = comps; l != NULL; l = l->next) {
 		ECalComponent *component = E_CAL_COMPONENT (l->data);
 
-		if (pstatus == ICAL_PARTSTAT_DECLINED) {
+		if (is_declined) {
 			ECalComponentId *id = e_cal_component_get_id (component);
 
 			if (e_cal_backend_cache_remove_component (priv->cache, id->uid, id->rid)) {
@@ -626,9 +627,9 @@ static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *ic
 
 			}
 
-		} 
+		}
 		else {
-			char *comp_str = NULL;
+			gchar *comp_str = NULL;
 
 			/* change_status (component, pstatus, e_gw_connection_get_user_email (priv->cnc)); */
 			e_cal_backend_cache_put_component (priv->cache, component);
@@ -652,14 +653,14 @@ static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *ic
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_receive_objects (ECalBackendSync *backend, EDataCal *cal, const char *calobj)
+e_cal_backend_google_receive_objects (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
 	icalcomponent *icalcomp, *subcomp;
 	icalcomponent_kind kind;
 	ECalBackendSyncStatus status = GNOME_Evolution_Calendar_Success;
-		
+
 	cbgo = (ECalBackendGoogle *)backend;
 	priv = cbgo->priv;
 
@@ -667,46 +668,46 @@ e_cal_backend_google_receive_objects (ECalBackendSync *backend, EDataCal *cal, c
 		in_offline (cbgo);
 		return GNOME_Evolution_Calendar_RepositoryOffline;
 	}
-	
-	icalcomp = icalparser_parse_string (calobj);	
+
+	icalcomp = icalparser_parse_string (calobj);
 	if (!icalcomp)
 		return GNOME_Evolution_Calendar_InvalidObject;
 
 	kind = icalcomponent_isa (icalcomp);
 	if (kind == ICAL_VCALENDAR_COMPONENT) {
 		subcomp = icalcomponent_get_first_component (icalcomp, e_cal_backend_get_kind (E_CAL_BACKEND(backend)));
-		
+
 		while (subcomp) {
 			icalcomponent_set_method (subcomp, icalcomponent_get_method (icalcomp));
-			status = receive_object (cbgo, cal, subcomp);	
-		
-			if (status != GNOME_Evolution_Calendar_Success)	
+			status = receive_object (cbgo, cal, subcomp);
+
+			if (status != GNOME_Evolution_Calendar_Success)
 				break;
 			subcomp = icalcomponent_get_next_component (icalcomp, e_cal_backend_get_kind (E_CAL_BACKEND(backend)));
 		}
-	} else if (kind == e_cal_backend_get_kind (E_CAL_BACKEND(backend))) {	
+	} else if (kind == e_cal_backend_get_kind (E_CAL_BACKEND(backend))) {
 		status = receive_object (cbgo, cal, icalcomp);
-	} else 
-		status = GNOME_Evolution_Calendar_InvalidObject;	
+	} else
+		status = GNOME_Evolution_Calendar_InvalidObject;
 
 	icalcomponent_free (icalcomp);
 
 	return status;
 }
 
-static ECalBackendSyncStatus 
+static ECalBackendSyncStatus
 send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, icalproperty_method method)
 {
 	ECalComponent *comp, *found_comp = NULL;
 	ECalBackendGooglePrivate *priv;
 	ECalBackendSyncStatus status = GNOME_Evolution_Calendar_OtherError;
-	const char *uid;
+	const gchar *uid;
 
 	priv = cbgo->priv;
 	comp = e_cal_component_new ();
-	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));	
+	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));
 
-	e_cal_component_get_uid (comp, (const char **)&uid);
+	e_cal_component_get_uid (comp, (const gchar **)&uid);
 	found_comp = e_cal_backend_cache_get_component (priv->cache, uid, NULL);
 
 	if (!found_comp) {
@@ -714,22 +715,22 @@ send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, ic
 		return GNOME_Evolution_Calendar_InvalidObject;
 	}
 
-	status = GNOME_Evolution_Calendar_Success;	
+	status = GNOME_Evolution_Calendar_Success;
 	/* TODO Check if connection exists */
 	switch (priv->mode) {
 		case CAL_MODE_ANY:
-		case CAL_MODE_REMOTE: 	
+		case CAL_MODE_REMOTE:
 			if (method == ICAL_METHOD_CANCEL) {
 				gboolean instances = FALSE;
 				if (instances) {
-					char *old_object = NULL;
+					gchar *old_object = NULL;
 					GSList *l = NULL, *comp_list;
 					comp_list = e_cal_backend_cache_get_components_by_uid (priv->cache, uid);
-		
+
 					for (l = comp_list; l; l = l->next) {
 						ECalComponent *component = E_CAL_COMPONENT (l->data);
 						ECalComponentId *cid = e_cal_component_get_id (component);
-						char *object = e_cal_component_get_as_string (component);
+						gchar *object = e_cal_component_get_as_string (component);
 
 						if (e_cal_backend_cache_remove_component (priv->cache, cid->uid,
 									cid->rid))
@@ -739,12 +740,12 @@ send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, ic
 						g_free (object);
 						g_object_unref (component);
 					}
-						
-					g_slist_free (comp_list);	
+
+					g_slist_free (comp_list);
 					g_free (old_object);
 				} else {
 					ECalComponentId *cid;
-					char * object;
+					gchar * object;
 
 					cid = e_cal_component_get_id (comp);
 					icalcomp = e_cal_component_get_icalcomponent (comp);
@@ -758,13 +759,13 @@ send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, ic
 
 					g_free (object);
 					e_cal_component_free_id (cid);
-				}	
+				}
 			}
 			break;
 		case CAL_MODE_LOCAL:
 			status = GNOME_Evolution_Calendar_RepositoryOffline;
 			break;
-		default: 
+		default:
 			break;
 	}
 
@@ -775,7 +776,7 @@ send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, ic
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, const char *calobj, GList **users, char **modified_calobj)
+e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj, GList **users, gchar **modified_calobj)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -783,7 +784,7 @@ e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, cons
 	icalcomponent *icalcomp, *subcomp;
 	icalcomponent_kind kind;
 	icalproperty_method method;
-		
+
 	cbgo = E_CAL_BACKEND_GOOGLE(backend);
 	priv = cbgo->priv;
 	if (priv->mode == CAL_MODE_LOCAL) {
@@ -794,23 +795,23 @@ e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, cons
 	icalcomp = icalparser_parse_string (calobj);
 	if (!icalcomp)
 		return GNOME_Evolution_Calendar_InvalidObject;
-	
+
 	method = icalcomponent_get_method (icalcomp);
 	kind = icalcomponent_isa (icalcomp);
-	
-	if (kind == ICAL_VCALENDAR_COMPONENT) {		
+
+	if (kind == ICAL_VCALENDAR_COMPONENT) {
 		subcomp = icalcomponent_get_first_component (icalcomp, e_cal_backend_get_kind(E_CAL_BACKEND(backend)));
 		while (subcomp) {
 			status = send_object (cbgo, cal, subcomp, method);
-				
+
 			if (status != GNOME_Evolution_Calendar_Success)
 				break;
 			subcomp = icalcomponent_get_next_component (icalcomp, e_cal_backend_get_kind (E_CAL_BACKEND(backend)));
 		}
 	} else if (kind == e_cal_backend_get_kind (E_CAL_BACKEND(backend))) {
-		status = send_object (cbgo, cal, icalcomp, method);	
-	} else 
-		status = GNOME_Evolution_Calendar_InvalidObject;		
+		status = send_object (cbgo, cal, icalcomp, method);
+	} else
+		status = GNOME_Evolution_Calendar_InvalidObject;
 	if (status == GNOME_Evolution_Calendar_Success) {
 		ECalComponent *comp;
 
@@ -821,7 +822,7 @@ e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, cons
 			e_cal_component_get_attendee_list (comp, &attendee_list);
 			/* convert this into GList */
 			for (tmp = attendee_list; tmp; tmp = g_slist_next (tmp)) {
-				const char *attendee = tmp->data;
+				const gchar *attendee = tmp->data;
 
 				if (attendee)
 					*users = g_list_append (*users, g_strdup (attendee));
@@ -831,14 +832,14 @@ e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, cons
 		}
 		*modified_calobj = g_strdup (calobj);
 	}
-	g_printf ("\n %s, %s \n", *modified_calobj, G_STRLOC);	
-	icalcomponent_free (icalcomp);	
+	g_printf ("\n %s, %s \n", *modified_calobj, G_STRLOC);
+	icalcomponent_free (icalcomp);
 
 	return status;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_changes (ECalBackendSync *backend, EDataCal *cal, const char *change_id, GList **adds, GList **modifies, GList **deletes)
+e_cal_backend_google_get_changes (ECalBackendSync *backend, EDataCal *cal, const gchar *change_id, GList **adds, GList **modifies, GList **deletes)
 {
 	/* FIXME Not Implemented */
 	return GNOME_Evolution_Calendar_Success;
@@ -854,10 +855,9 @@ e_cal_backend_google_is_read_only (ECalBackendSync *backend, EDataCal *cal, gboo
 	return GNOME_Evolution_Calendar_Success;
 }
 
-
 /* Returns the email address of the person who opened the calendar */
 static ECalBackendSyncStatus
-e_cal_backend_google_get_cal_address (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_google_get_cal_address (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -871,7 +871,7 @@ e_cal_backend_google_get_cal_address (ECalBackendSync *backend, EDataCal *cal, c
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_alarm_email_address (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_google_get_alarm_email_address (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
 	/* Support email based alarms ? */
 
@@ -881,14 +881,14 @@ e_cal_backend_google_get_alarm_email_address (ECalBackendSync *backend, EDataCal
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_modify_object (ECalBackendSync *backend, EDataCal *cal, const char *calobj, CalObjModType mod, char **old_object, char **new_object)
+e_cal_backend_google_modify_object (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj, CalObjModType mod, gchar **old_object, gchar **new_object)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
 	icalcomponent *icalcomp;
 	ECalComponent *comp = NULL, *cache_comp = NULL;
 	EGoItem *item;
-	const char *uid=NULL, *rid=NULL;
+	const gchar *uid=NULL, *rid=NULL;
 	GDataEntry *entry, *entry_from_server=NULL, *updated_entry=NULL;
 	gchar *edit_link;
 	GSList *l;
@@ -944,11 +944,11 @@ e_cal_backend_google_modify_object (ECalBackendSync *backend, EDataCal *cal, con
 			}
 
 			edit_link = gdata_entry_get_edit_link (entry_from_server);
-			updated_entry = gdata_service_update_entry_with_link (GDATA_SERVICE (priv->service), 
+			updated_entry = gdata_service_update_entry_with_link (GDATA_SERVICE (priv->service),
 					entry, edit_link, NULL);
 
 			if (updated_entry) {
-				/* FIXME Response from server contains, additional info about GDataEntry 
+				/* FIXME Response from server contains, additional info about GDataEntry
 				 * Store and use them later
 				 */
 			}
@@ -968,18 +968,17 @@ e_cal_backend_google_modify_object (ECalBackendSync *backend, EDataCal *cal, con
 	return GNOME_Evolution_Calendar_Success;
 }
 
-
 static ECalBackendSyncStatus
 e_cal_backend_google_remove_object (ECalBackendSync *backend, EDataCal *cal,
-				       const char *uid, const char *rid,
-				       CalObjModType mod, char **old_object,
-				       char **object)
+				       const gchar *uid, const gchar *rid,
+				       CalObjModType mod, gchar **old_object,
+				       gchar **object)
 {
 	ECalBackendGoogle *cbgo;
 	GDataEntry *entry;
 	ECalBackendGooglePrivate *priv;
 	ECalComponent *comp = NULL;
-	char *calobj = NULL;
+	gchar *calobj = NULL;
 	GSList *entries = NULL;
 	EGoItem *item;
 
@@ -997,7 +996,7 @@ e_cal_backend_google_remove_object (ECalBackendSync *backend, EDataCal *cal,
 		ECalBackendSyncStatus status;
 		icalcomponent *icalcomp;
 		ECalComponentId *id;
-		char *comp_str;
+		gchar *comp_str;
 
 		status = e_cal_backend_google_get_object (backend, cal, uid, rid, &calobj);
 
@@ -1034,7 +1033,7 @@ e_cal_backend_google_remove_object (ECalBackendSync *backend, EDataCal *cal,
 			return GNOME_Evolution_Calendar_InvalidObject;
 		}
 
-	        gdata_service_delete_entry (GDATA_SERVICE(priv->service), entry, NULL);
+		gdata_service_delete_entry (GDATA_SERVICE(priv->service), entry, NULL);
 		*object = NULL;
 		*old_object = strdup (calobj);
 	}
@@ -1048,7 +1047,7 @@ e_cal_backend_google_remove_object (ECalBackendSync *backend, EDataCal *cal,
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_create_object (ECalBackendSync *backend, EDataCal *cal, char **calobj, char **uid)
+e_cal_backend_google_create_object (ECalBackendSync *backend, EDataCal *cal, gchar **calobj, gchar **uid)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -1117,7 +1116,7 @@ e_cal_backend_google_create_object (ECalBackendSync *backend, EDataCal *cal, cha
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal, char **attribute)
+e_cal_backend_google_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal, gchar **attribute)
 {
 	/* ldap attribute is specific to Sun ONE connector to get free busy information*/
 	/* return NULL here as google backend know how to get free busy information */
@@ -1127,9 +1126,8 @@ e_cal_backend_google_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal
 	return GNOME_Evolution_Calendar_Success;
 }
 
-
 static ECalBackendSyncStatus
-e_cal_backend_google_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, char **capabilities)
+e_cal_backend_google_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, gchar **capabilities)
 {
 	/* FIXME */
 	*capabilities = NULL;
@@ -1137,14 +1135,15 @@ e_cal_backend_google_get_static_capabilities (ECalBackendSync *backend, EDataCal
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists,const char *username, const char *password)
+e_cal_backend_google_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists,const gchar *username, const gchar *password)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
 	ECalBackendSyncStatus status;
 	ECalSourceType source_type;
-	gchar *source = NULL, *mangled_uri = NULL, *filename = NULL;
-	int i;
+	const gchar *source = NULL;
+	gchar *mangled_uri = NULL, *filename = NULL;
+	gint i;
 
 	cbgo = E_CAL_BACKEND_GOOGLE(backend);
 	priv = cbgo->priv;
@@ -1171,13 +1170,13 @@ e_cal_backend_google_open (ECalBackendSync *backend, EDataCal *cal, gboolean onl
 	/* Not for remote */
 	if (priv->mode == CAL_MODE_LOCAL) {
 		ESource *esource;
-		const char *display_contents = NULL;
+		const gchar *display_contents = NULL;
 
 		cbgo->priv->read_only = TRUE;
 		esource = e_cal_backend_get_source (E_CAL_BACKEND(cbgo));
-		display_contents = e_source_get_property (esource, "offline-sync");
+		display_contents = e_source_get_property (esource, "offline_sync");
 
-		if(!display_contents || !g_str_equal (display_contents, "1")) {
+		if (!display_contents || !g_str_equal (display_contents, "1")) {
 			g_mutex_unlock(priv->mutex);
 			return GNOME_Evolution_Calendar_RepositoryOffline;
 		}
@@ -1212,11 +1211,11 @@ e_cal_backend_google_open (ECalBackendSync *backend, EDataCal *cal, gboolean onl
 			mangled_uri[i] = '_';
 		}
 	}
-	
-	filename = g_build_filename (g_get_home_dir (), 
+
+	filename = g_build_filename (g_get_home_dir (),
 				     ".evolution/cache", source,
 				     mangled_uri,
-			             NULL);
+				     NULL);
 
 	g_free (mangled_uri);
 	priv->local_attachments_store = g_filename_to_uri (filename, NULL, NULL);
@@ -1281,7 +1280,6 @@ e_cal_backend_google_finalize (GObject *object)
 		priv->cache = NULL;
 	}
 
-
 	if (priv->default_zone) {
 		icaltimezone_free (priv->default_zone, 1);
 		priv->default_zone = NULL;
@@ -1292,6 +1290,11 @@ e_cal_backend_google_finalize (GObject *object)
 		priv->timeout_id = 0;
 	}
 
+	if (priv->proxy) {
+		g_object_unref (priv->proxy);
+		priv->proxy = NULL;
+	}
+
 	g_free (priv);
 	cbgo->priv = NULL;
 
@@ -1300,6 +1303,22 @@ e_cal_backend_google_finalize (GObject *object)
 	}
 }
 
+static void
+proxy_settings_changed (EProxy *proxy, gpointer user_data)
+{
+	SoupURI *proxy_uri = NULL;
+
+	ECalBackendGooglePrivate *priv = (ECalBackendGooglePrivate *)user_data;
+	if (!priv || !priv->uri)
+		return;
+
+	/* use proxy if necessary */
+	if (e_proxy_require_proxy_for_uri (proxy, priv->uri)) {
+		proxy_uri = e_proxy_peek_uri_for (proxy, priv->uri);
+	}
+	gdata_service_set_proxy (GDATA_SERVICE (priv->service), proxy_uri);
+}
+
 /* Object initialisation function for google backend */
 static void
 e_cal_backend_google_init (ECalBackendGoogle *cbgo, ECalBackendGoogleClass *class)
@@ -1316,6 +1335,10 @@ e_cal_backend_google_init (ECalBackendGoogle *cbgo, ECalBackendGoogleClass *clas
 	priv->timeout_id = 0;
 	cbgo->priv = priv;
 
+	priv->proxy = e_proxy_new ();
+	e_proxy_setup_proxy (priv->proxy);
+	g_signal_connect (priv->proxy, "changed", G_CALLBACK (proxy_settings_changed), priv);
+
 	/* FIXME set a lock */
 	e_cal_backend_sync_set_lock (E_CAL_BACKEND_SYNC (cbgo), TRUE);
 }
@@ -1382,7 +1405,7 @@ e_cal_backend_google_class_init (ECalBackendGoogleClass *class)
  * Return value: The type id of the #ECalBackendGoogle class.
  **/
 GType
-e_cal_backend_google_get_type ()
+e_cal_backend_google_get_type (void)
 {
 	static	GType e_cal_backend_google_type = 0;
 
@@ -1403,7 +1426,6 @@ e_cal_backend_google_get_type ()
 	return e_cal_backend_google_type;
 }
 
-
 /***************************************** Helper Functions ****************************************************/
 
 /**
@@ -1473,12 +1495,20 @@ void
 e_cal_backend_google_set_uri (ECalBackendGoogle *cbgo, gchar *uri)
 {
 	ECalBackendGooglePrivate *priv;
+	SoupURI *proxy_uri = NULL;
 
 	g_return_if_fail (cbgo != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND_GOOGLE(cbgo));
 
 	priv = cbgo->priv;
 	priv->uri = uri;
+
+	/* use proxy if necessary */
+	if (e_proxy_require_proxy_for_uri (priv->proxy, priv->uri)) {
+		proxy_uri = e_proxy_peek_uri_for (priv->proxy, priv->uri);
+	}
+
+	gdata_service_set_proxy (GDATA_SERVICE (priv->service), proxy_uri);
 }
 
 /**
@@ -1508,7 +1538,7 @@ e_cal_backend_google_set_entry (ECalBackendGoogle *cbgo, GDataEntry *entry)
  *
  **/
 void
-e_cal_backend_google_set_timeout_id (ECalBackendGoogle *cbgo,gint timeout_id )
+e_cal_backend_google_set_timeout_id (ECalBackendGoogle *cbgo, guint timeout_id)
 {
 	ECalBackendGooglePrivate *priv;
 	priv = cbgo->priv;
@@ -1572,7 +1602,6 @@ e_cal_backend_google_get_cache (ECalBackendGoogle *cbgo)
 	g_return_val_if_fail (cbgo != NULL, NULL);
 	g_return_val_if_fail (E_IS_CAL_BACKEND_GOOGLE(cbgo), NULL);
 
-
 	priv = cbgo->priv;
 	return priv->cache;
 }
@@ -1653,7 +1682,7 @@ e_cal_backend_google_get_entry (ECalBackendGoogle *cbgo)
  * Gets the timeout id.
  *
  **/
-gint
+guint
 e_cal_backend_google_get_timeout_id (ECalBackendGoogle *cbgo)
 {
 	ECalBackendGooglePrivate *priv;
@@ -1701,12 +1730,11 @@ e_cal_backend_google_get_password (ECalBackendGoogle *cbgo)
 	return priv->password;
 }
 
-
 gchar *
 e_cal_backend_google_get_local_attachments_store (ECalBackendGoogle *cbgo)
 {
 	ECalBackendGooglePrivate *priv;
-	
+
 	g_return_val_if_fail (cbgo != NULL, NULL);
 	g_return_val_if_fail (E_IS_CAL_BACKEND_GOOGLE(cbgo), NULL);
 
