@@ -1,7 +1,6 @@
 /* Evolution calendar utilities and types
  *
- * Copyright (C) 2000 Ximian, Inc.
- * Copyright (C) 2000 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Author: Federico Mena-Quintero <federico@ximian.com>
  *
@@ -16,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef E_CAL_UTIL_H
@@ -36,7 +35,7 @@ G_BEGIN_DECLS
  * recurrence, or an alarm trigger of a `real' calendar object.
  */
 typedef struct {
-	char *uid;			/* UID of the object */
+	gchar *uid;			/* UID of the object */
 	time_t start;			/* Start time of instance */
 	time_t end;			/* End time of instance */
 } CalObjInstance;
@@ -69,8 +68,8 @@ void cal_obj_uid_list_free (GList *list);
 icalcomponent *e_cal_util_new_top_level (void);
 icalcomponent *e_cal_util_new_component (icalcomponent_kind kind);
 
-icalcomponent *e_cal_util_parse_ics_string (const char *string);
-icalcomponent *e_cal_util_parse_ics_file (const char *filename);
+icalcomponent *e_cal_util_parse_ics_string (const gchar *string);
+icalcomponent *e_cal_util_parse_ics_file (const gchar *filename);
 
 ECalComponentAlarms *e_cal_util_generate_alarms_for_comp (ECalComponent *comp,
 						       time_t start,
@@ -79,7 +78,7 @@ ECalComponentAlarms *e_cal_util_generate_alarms_for_comp (ECalComponent *comp,
 						       ECalRecurResolveTimezoneFn resolve_tzid,
 						       gpointer user_data,
 						       icaltimezone *default_timezone);
-int e_cal_util_generate_alarms_for_list (GList *comps,
+gint e_cal_util_generate_alarms_for_list (GList *comps,
 				       time_t start,
 				       time_t end,
 				       ECalComponentAlarmAction *omit,
@@ -88,10 +87,8 @@ int e_cal_util_generate_alarms_for_list (GList *comps,
 				       gpointer user_data,
 				       icaltimezone *default_timezone);
 
-icaltimezone *e_cal_util_resolve_tzid (const char *tzid, gpointer data);
-
-char *e_cal_util_priority_to_string (int priority);
-int e_cal_util_priority_from_string (const char *string);
+const gchar *e_cal_util_priority_to_string (gint priority);
+gint e_cal_util_priority_from_string (const gchar *string);
 
 void e_cal_util_add_timezones_from_component (icalcomponent *vcal_comp,
 					    icalcomponent *icalcomp);
@@ -118,6 +115,7 @@ gboolean e_cal_util_event_dates_match (icalcomponent *icalcomp1, icalcomponent *
 #define CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ATTEND       "organizer-must-attend"
 #define CAL_STATIC_CAPABILITY_ORGANIZER_NOT_EMAIL_ADDRESS "organizer-not-email-address"
 #define CAL_STATIC_CAPABILITY_REMOVE_ALARMS               "remove-alarms"
+#define CAL_STATIC_CAPABILITY_CREATE_MESSAGES             "create-messages"
 #define CAL_STATIC_CAPABILITY_SAVE_SCHEDULES              "save-schedules"
 #define CAL_STATIC_CAPABILITY_NO_CONV_TO_ASSIGN_TASK	  "no-conv-to-assign-task"
 #define CAL_STATIC_CAPABILITY_NO_CONV_TO_RECUR		  "no-conv-to-recur"
@@ -137,7 +135,9 @@ void           e_cal_util_remove_instances (icalcomponent *icalcomp,
 					  struct icaltimetype rid,
 					  CalObjModType mod);
 
+gchar *e_cal_util_get_system_timezone_location (void);
+icaltimezone *e_cal_util_get_system_timezone (void);
+
 G_END_DECLS
 
 #endif
-
