@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-store.h : Abstract class for an email store */
 
-/* 
+/*
  *
  * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
  *          Michael Zucchi <NotZed@ximian.com>
@@ -9,8 +9,8 @@
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -44,9 +44,9 @@ typedef struct _CamelFolderInfo {
 	struct _CamelFolderInfo *parent;
 	struct _CamelFolderInfo *child;
 
-	char *uri;
-	char *name;
-	char *full_name;
+	gchar *uri;
+	gchar *name;
+	gchar *full_name;
 
 	guint32 flags;
 	gint32 unread;
@@ -100,7 +100,7 @@ typedef struct _CamelFolderInfo {
 
 /* Structure of rename event's event_data */
 typedef struct _CamelRenameInfo {
-	char *old_base;
+	gchar *old_base;
 	struct _CamelFolderInfo *new;
 } CamelRenameInfo;
 
@@ -115,13 +115,14 @@ typedef struct _CamelRenameInfo {
 #define CAMEL_STORE_FILTER_INBOX	(1 << 2)
 #define CAMEL_STORE_VJUNK		(1 << 3)
 #define CAMEL_STORE_PROXY		(1 << 4)
+#define CAMEL_STORE_IS_MIGRATING (1 << 5)
 
 struct _CamelDB;
 
 struct _CamelStore {
 	CamelService parent_object;
 	struct _CamelStorePrivate *priv;
-	
+
 	CamelObjectBag *folders;
 	struct _CamelDB *cdb_r;
 	struct _CamelDB *cdb_w;
@@ -147,6 +148,11 @@ struct _CamelStore {
 #define CAMEL_STORE_FOLDER_INFO_RECURSIVE  (1 << 1)
 #define CAMEL_STORE_FOLDER_INFO_SUBSCRIBED (1 << 2)
 #define CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL (1 << 3)  /* don't include vTrash/vJunk folders */
+/* Fetch only the subscription list. Clients should use this */
+/* flag for requesting the list of folders available for  */
+/* subscription. Used in Exchange / IMAP  connectors for public */
+/* folder fetching */
+#define CAMEL_STORE_FOLDER_INFO_SUBSCRIPTION_LIST (1 << 4)
 
 typedef struct {
 	CamelServiceClass parent_class;
@@ -155,42 +161,42 @@ typedef struct {
 	GCompareFunc    compare_folder_name;
 
 	CamelFolder *   (*get_folder)               (CamelStore *store,
-						     const char *folder_name,
+						     const gchar *folder_name,
 						     guint32 flags,
 						     CamelException *ex);
 
-	CamelFolder *   (*get_inbox)                (CamelStore *store, CamelException *ex);	
+	CamelFolder *   (*get_inbox)                (CamelStore *store, CamelException *ex);
 	CamelFolder *   (*get_trash)                (CamelStore *store, CamelException *ex);
 	CamelFolder *   (*get_junk)                 (CamelStore *store, CamelException *ex);
-	
+
 	CamelFolderInfo *(*create_folder)           (CamelStore *store,
-						     const char *parent_name,
-						     const char *folder_name,
+						     const gchar *parent_name,
+						     const gchar *folder_name,
 						     CamelException *ex);
 	void            (*delete_folder)            (CamelStore *store,
-						     const char *folder_name,
+						     const gchar *folder_name,
 						     CamelException *ex);
 	void		(*rename_folder)	    (CamelStore *store,
-						     const char *old_name,
-						     const char *new_name,
+						     const gchar *old_name,
+						     const gchar *new_name,
 						     CamelException *ex);
-	
-	void            (*sync)                     (CamelStore *store, int expunge, CamelException *ex);
-	
+
+	void            (*sync)                     (CamelStore *store, gint expunge, CamelException *ex);
+
 	CamelFolderInfo *(*get_folder_info)         (CamelStore *store,
-						     const char *top,
+						     const gchar *top,
 						     guint32 flags,
 						     CamelException *ex);
 	void            (*free_folder_info)         (CamelStore *store,
 						     CamelFolderInfo *fi);
-	
+
 	gboolean        (*folder_subscribed)        (CamelStore *store,
-						     const char *folder_name);
+						     const gchar *folder_name);
 	void            (*subscribe_folder)         (CamelStore *store,
-						     const char *folder_name,
+						     const gchar *folder_name,
 						     CamelException *ex);
 	void            (*unsubscribe_folder)       (CamelStore *store,
-						     const char *folder_name,
+						     const gchar *folder_name,
 						     CamelException *ex);
 	void            (*noop)                     (CamelStore *store,
 						     CamelException *ex);
@@ -206,9 +212,9 @@ CamelType camel_store_get_type (void);
 
 /* public methods */
 CamelFolder *    camel_store_get_folder         (CamelStore *store,
-					         const char *folder_name,
+						 const gchar *folder_name,
 						 guint32 flags,
-					         CamelException *ex);
+						 CamelException *ex);
 CamelFolder *    camel_store_get_inbox          (CamelStore *store,
 						 CamelException *ex);
 CamelFolder *    camel_store_get_trash          (CamelStore *store,
@@ -217,21 +223,21 @@ CamelFolder *    camel_store_get_junk           (CamelStore *store,
 						 CamelException *ex);
 
 CamelFolderInfo *camel_store_create_folder      (CamelStore *store,
-						 const char *parent_name,
-						 const char *folder_name,
+						 const gchar *parent_name,
+						 const gchar *folder_name,
 						 CamelException *ex);
 void             camel_store_delete_folder      (CamelStore *store,
-						 const char *folder_name,
+						 const gchar *folder_name,
 						 CamelException *ex);
 void             camel_store_rename_folder      (CamelStore *store,
-						 const char *old_namein,
-						 const char *new_name,
+						 const gchar *old_namein,
+						 const gchar *new_name,
 						 CamelException *ex);
 
-void             camel_store_sync               (CamelStore *store, int expunge, CamelException *ex);
+void             camel_store_sync               (CamelStore *store, gint expunge, CamelException *ex);
 
 CamelFolderInfo *camel_store_get_folder_info    (CamelStore *store,
-						 const char *top,
+						 const gchar *top,
 						 guint32 flags,
 						 CamelException *ex);
 void             camel_store_free_folder_info   (CamelStore *store,
@@ -246,8 +252,8 @@ CamelFolderInfo *camel_folder_info_new             (void);
 void             camel_folder_info_free            (CamelFolderInfo *fi);
 #ifndef CAMEL_DISABLE_DEPRECATED
 CamelFolderInfo *camel_folder_info_build           (GPtrArray *folders,
-						    const char *namespace,
-						    char separator,
+						    const gchar *namespace,
+						    gchar separator,
 						    gboolean short_names);
 #endif /* CAMEL_DISABLE_DEPRECATED */
 CamelFolderInfo *camel_folder_info_clone	   (CamelFolderInfo *fi);
@@ -255,20 +261,20 @@ CamelFolderInfo *camel_folder_info_clone	   (CamelFolderInfo *fi);
 gboolean         camel_store_supports_subscriptions   (CamelStore *store);
 
 gboolean         camel_store_folder_subscribed        (CamelStore *store,
-						       const char *folder_name);
+						       const gchar *folder_name);
 void             camel_store_subscribe_folder         (CamelStore *store,
-						       const char *folder_name,
+						       const gchar *folder_name,
 						       CamelException *ex);
 void             camel_store_unsubscribe_folder       (CamelStore *store,
-						       const char *folder_name,
+						       const gchar *folder_name,
 						       CamelException *ex);
 
 void             camel_store_noop                     (CamelStore *store,
 						       CamelException *ex);
 
-int              camel_store_folder_uri_equal         (CamelStore *store,
-						       const char *uri0,
-						       const char *uri1);
+gint              camel_store_folder_uri_equal         (CamelStore *store,
+						       const gchar *uri0,
+						       const gchar *uri1);
 
 gboolean         camel_store_can_refresh_folder       (CamelStore *store,
 						       CamelFolderInfo *info,
@@ -279,15 +285,15 @@ typedef struct _CamelISubscribe CamelISubscribe;
 struct _CamelISubscribe {
 	CamelInterface iface;
 
-	gboolean (*subscribed)(CamelStore *store, const char *folder_name);
-	void (*subscribe)(CamelStore *store, const char *folder_name, CamelException *ex);
-	void (*unsubscribe)(CamelStore *store, const char *folder_name, CamelException *ex);
+	gboolean (*subscribed)(CamelStore *store, const gchar *folder_name);
+	void (*subscribe)(CamelStore *store, const gchar *folder_name, CamelException *ex);
+	void (*unsubscribe)(CamelStore *store, const gchar *folder_name, CamelException *ex);
 };
 
 CamelType camel_isubscribe_get_type (void);
-gboolean camel_isubscribe_subscribed(CamelStore *store, const char *name);
-void camel_isubscribe_subscribe(CamelStore *store, const char *folder_name, CamelException *ex);
-void camel_isubscribe_unsubscribe(CamelStore *store, const char *folder_name, CamelException *ex);
+gboolean camel_isubscribe_subscribed(CamelStore *store, const gchar *name);
+void camel_isubscribe_subscribe(CamelStore *store, const gchar *folder_name, CamelException *ex);
+void camel_isubscribe_unsubscribe(CamelStore *store, const gchar *folder_name, CamelException *ex);
 #endif /* CAMEL_DISABLE_DEPRECATED */
 
 G_END_DECLS
