@@ -252,12 +252,10 @@ camel_vee_folder_remove_folder(CamelVeeFolder *vf, CamelFolder *sub)
 		return;
 	}
 
-
 	camel_object_unhook_event((CamelObject *)sub, "folder_changed", (CamelObjectEventHookFunc) folder_changed, vf);
 	camel_object_unhook_event((CamelObject *)sub, "deleted", (CamelObjectEventHookFunc) subfolder_deleted, vf);
 	camel_object_unhook_event((CamelObject *)sub, "renamed", (CamelObjectEventHookFunc) folder_renamed, vf);
 
-
 	p->folders = g_list_remove(p->folders, sub);
 
 	/* undo the freeze state that we have imposed on this source folder */
@@ -584,7 +582,6 @@ vee_sync(CamelFolder *folder, gboolean expunge, CamelException *ex)
 		} else
 			camel_exception_clear (ex);
 
-
 		/* auto update vfolders shouldn't need a rebuild */
 /*		if ((vf->flags & CAMEL_STORE_VEE_FOLDER_AUTO) == 0 */
 /*		    && camel_vee_folder_rebuild_folder(vf, f, ex) == -1) */
@@ -692,7 +689,6 @@ vee_count_by_expression(CamelFolder *folder, const gchar *expression, CamelExcep
 		node = g_list_next(node);
 	}
 
-
 	g_free(expr);
 
 	g_hash_table_destroy(searched);
@@ -744,7 +740,6 @@ vee_search_by_expression(CamelFolder *folder, const gchar *expression, CamelExce
 		node = g_list_next(node);
 	}
 
-
 	g_free(expr);
 
 	g_hash_table_destroy(searched);
@@ -1052,10 +1047,12 @@ unmatched_check_uid(gchar *uidin, gpointer value, struct _update_data *u)
 	} else {
 		CamelVeeMessageInfo *mi = (CamelVeeMessageInfo *)camel_folder_summary_uid(((CamelFolder *)u->folder_unmatched)->summary, uid);
 		if (mi) {
-			camel_db_delete_uid_from_vfolder_transaction (((CamelFolder *)u->folder_unmatched)->parent_store->cdb_w, ((CamelFolder *)u->folder_unmatched)->full_name, uid, NULL);
+			CamelException ex = CAMEL_EXCEPTION_INITIALISER;
+			camel_db_delete_uid_from_vfolder_transaction (((CamelFolder *)u->folder_unmatched)->parent_store->cdb_w, ((CamelFolder *)u->folder_unmatched)->full_name, uid, &ex);
 			camel_folder_summary_remove_uid_fast (((CamelFolder *)u->folder_unmatched)->summary, uid);
 			camel_folder_change_info_remove_uid(u->folder_unmatched->changes, uid);
 			camel_message_info_free((CamelMessageInfo *)mi);
+			camel_exception_clear (&ex);
 		}
 	}
 }
@@ -1073,8 +1070,11 @@ folder_added_uid(gchar *uidin, gpointer value, struct _update_data *u)
 		/* FIXME[disk-summary] Handle exceptions */
 		/* FIXME[disk-summary] Make all these as transactions, just
 		 * testing atm */
-		if (u->rebuilt && !u->correlating)
-			camel_db_add_to_vfolder_transaction (((CamelFolder *) u->vf)->parent_store->cdb_w, ((CamelFolder *) u->vf)->full_name, (gchar *) camel_message_info_uid(mi), NULL);
+		if (u->rebuilt && !u->correlating) {
+			CamelException ex = CAMEL_EXCEPTION_INITIALISER;
+			camel_db_add_to_vfolder_transaction (((CamelFolder *) u->vf)->parent_store->cdb_w, ((CamelFolder *) u->vf)->full_name, (gchar *) camel_message_info_uid(mi), &ex);
+			camel_exception_clear (&ex);
+		}
 		if (!CAMEL_IS_VEE_FOLDER(u->source) && u->unmatched_uids != NULL) {
 			if (g_hash_table_lookup_extended(u->unmatched_uids, camel_message_info_uid(mi), (gpointer *)&oldkey, &oldval)) {
 				n = GPOINTER_TO_INT (oldval);
@@ -1086,7 +1086,6 @@ folder_added_uid(gchar *uidin, gpointer value, struct _update_data *u)
 	}
 }
 
-
 /* build query contents for a single folder */
 static gint
 vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
@@ -1094,7 +1093,6 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 	GPtrArray *match, *all;
 	GHashTable *allhash, *matchhash, *fullhash;
 	GSList *del_list = NULL;
-	CamelFolder *f = source;
 	CamelFolder *folder = (CamelFolder *)vf;
 	gint i, n, count, start, last;
 	struct _update_data u;
@@ -1130,7 +1128,7 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 			/* We take this to mean the results have not been cached.
 			 * XXX: It will also trigger if the result set is empty. */
 			match == NULL) {
-			match = camel_folder_search_by_expression(f, vf->expression, ex);
+			match = camel_folder_search_by_expression(source, vf->expression, ex);
 			if (match == NULL) /* Search failed */
 				return 0;
 			rebuilded = TRUE;
@@ -1149,21 +1147,22 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 
 	CAMEL_VEE_FOLDER_LOCK(vf, summary_lock);
 
-	/* we build 2 hash tables, one for all uid's not matched, the other for all matched uid's,
-	   we just ref the real memory */
+	/* we build 2 hash tables, one for all uid's not matched, the
+	   other for all matched uid's, we just ref the real memory */
 	matchhash = g_hash_table_new(g_str_hash, g_str_equal);
 	for (i=0;i<match->len;i++)
 		g_hash_table_insert(matchhash, match->pdata[i], GINT_TO_POINTER (1));
 
 	allhash = g_hash_table_new(g_str_hash, g_str_equal);
 	fullhash = g_hash_table_new(g_str_hash, g_str_equal);
-	all = camel_folder_summary_array(f->summary);
+	all = camel_folder_summary_array(source->summary);
 	for (i=0;i<all->len;i++) {
 		if (g_hash_table_lookup(matchhash, all->pdata[i]) == NULL)
 			g_hash_table_insert(allhash, all->pdata[i], GINT_TO_POINTER (1));
 		g_hash_table_insert(fullhash, all->pdata[i], GINT_TO_POINTER (1));
 
 	}
+	/* remove uids that can't be found in the source folder */
 	count = match->len;
 	for (i=0; i<count; i++) {
 		if (!g_hash_table_lookup(fullhash, match->pdata[i])) {
@@ -1179,7 +1178,9 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 	if (folder_unmatched != NULL)
 		CAMEL_VEE_FOLDER_LOCK(folder_unmatched, summary_lock);
 
-	/* scan, looking for "old" uid's to be removed */
+	/* scan, looking for "old" uid's to be removed. "old" uid's
+	   are those that are from previous added sources (not in
+	   current source) */
 	start = -1;
 	last = -1;
 	count = camel_folder_summary_count(folder->summary);
@@ -1276,8 +1277,11 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 
 	/* Del the unwanted things from the summary, we don't hold any locks now. */
 	if (del_list) {
-		if (!correlating)
-			camel_db_delete_vuids(folder->parent_store->cdb_w, folder->full_name, shash, del_list, NULL);
+		if (!correlating) {
+			CamelException ex = CAMEL_EXCEPTION_INITIALISER;
+			camel_db_delete_vuids(folder->parent_store->cdb_w, folder->full_name, shash, del_list, &ex);
+			camel_exception_clear (&ex);
+		}
 		((CamelVeeSummary *)folder->summary)->force_counts = TRUE;
 		g_slist_foreach (del_list, (GFunc) camel_pstring_free, NULL);
 		g_slist_free (del_list);
@@ -1293,8 +1297,8 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 		g_ptr_array_foreach (match, (GFunc) camel_pstring_free, NULL);
 		g_ptr_array_free(match, TRUE);
 	} else
-		camel_folder_search_free(f, match);
-	camel_folder_free_summary (f, all);
+		camel_folder_search_free(source, match);
+	camel_folder_free_summary (source, all);
 
 	if (unmatched_changes) {
 		camel_object_trigger_event((CamelObject *)folder_unmatched, "folder_changed", unmatched_changes);
@@ -1309,7 +1313,6 @@ vee_rebuild_folder(CamelVeeFolder *vf, CamelFolder *source, CamelException *ex)
 	return 0;
 }
 
-
 /* Hold all these with summary lock and unmatched summary lock held */
 static void
 folder_changed_add_uid(CamelFolder *sub, const gchar *uid, const gchar hash[8], CamelVeeFolder *vf, gboolean use_db)
@@ -1328,8 +1331,11 @@ folder_changed_add_uid(CamelFolder *sub, const gchar *uid, const gchar hash[8],
 		return;
 
 	vuid = camel_message_info_uid(vinfo);
-	if (use_db)
-		camel_db_add_to_vfolder_transaction (folder->parent_store->cdb_w, folder->full_name, (gchar *)vuid, NULL);
+	if (use_db) {
+		CamelException ex = CAMEL_EXCEPTION_INITIALISER;
+		camel_db_add_to_vfolder_transaction (folder->parent_store->cdb_w, folder->full_name, (gchar *)vuid, &ex);
+		camel_exception_clear (&ex);
+	}
 	camel_folder_change_info_add_uid(vf->changes,  vuid);
 	if ((vf->flags & CAMEL_STORE_FOLDER_PRIVATE) == 0 && !CAMEL_IS_VEE_FOLDER(sub) && folder_unmatched != NULL) {
 		if (g_hash_table_lookup_extended(unmatched_uids, vuid, (gpointer *)&oldkey, &oldval)) {
@@ -1340,10 +1346,12 @@ folder_changed_add_uid(CamelFolder *sub, const gchar *uid, const gchar hash[8],
 		}
 		vinfo = (CamelVeeMessageInfo *)camel_folder_get_message_info((CamelFolder *)folder_unmatched, vuid);
 		if (vinfo) {
+			CamelException ex = CAMEL_EXCEPTION_INITIALISER;
 			camel_folder_change_info_remove_uid(folder_unmatched->changes, vuid);
-			camel_db_delete_uid_from_vfolder_transaction (folder->parent_store->cdb_w, ((CamelFolder *)folder_unmatched)->full_name, vuid, NULL);
+			camel_db_delete_uid_from_vfolder_transaction (folder->parent_store->cdb_w, ((CamelFolder *)folder_unmatched)->full_name, vuid, &ex);
 			camel_folder_summary_remove_uid_fast(((CamelFolder *)folder_unmatched)->summary, vuid);
 			camel_folder_free_message_info((CamelFolder *)folder_unmatched, (CamelMessageInfo *)vinfo);
+			camel_exception_clear (&ex);
 		}
 	}
 }
@@ -1364,9 +1372,12 @@ folder_changed_remove_uid(CamelFolder *sub, const gchar *uid, const gchar hash[8
 	strcpy(vuid+8, uid);
 
 	camel_folder_change_info_remove_uid(vf->changes, vuid);
-	if (use_db)
+	if (use_db) {
 		/* FIXME[disk-summary] Handle exception */
-		camel_db_delete_uid_from_vfolder_transaction (folder->parent_store->cdb_w, folder->full_name, vuid, NULL);
+		CamelException ex = CAMEL_EXCEPTION_INITIALISER;
+		camel_db_delete_uid_from_vfolder_transaction (folder->parent_store->cdb_w, folder->full_name, vuid, &ex);
+		camel_exception_clear (&ex);
+	}
 	camel_folder_summary_remove_uid_fast(folder->summary, vuid);
 
 	if ((vf->flags & CAMEL_STORE_FOLDER_PRIVATE) == 0 && !CAMEL_IS_VEE_FOLDER(sub) && folder_unmatched != NULL) {
@@ -1393,10 +1404,12 @@ folder_changed_remove_uid(CamelFolder *sub, const gchar *uid, const gchar hash[8
 
 			vinfo = (CamelVeeMessageInfo *)camel_folder_get_message_info((CamelFolder *)folder_unmatched, vuid);
 			if (vinfo) {
+				CamelException ex = CAMEL_EXCEPTION_INITIALISER;
 				camel_folder_change_info_remove_uid(folder_unmatched->changes, vuid);
-				camel_db_delete_uid_from_vfolder_transaction (folder->parent_store->cdb_w, ((CamelFolder *)folder_unmatched)->full_name, vuid, NULL);
+				camel_db_delete_uid_from_vfolder_transaction (folder->parent_store->cdb_w, ((CamelFolder *)folder_unmatched)->full_name, vuid, &ex);
 				camel_folder_summary_remove_uid_fast(((CamelFolder *)folder_unmatched)->summary, vuid);
 				camel_folder_free_message_info((CamelFolder *)folder_unmatched, (CamelMessageInfo *)vinfo);
+				camel_exception_clear (&ex);
 			}
 		}
 	}
@@ -1485,13 +1498,14 @@ folder_changed_change(CamelSession *session, CamelSessionThreadMsg *msg)
 
 	camel_vee_folder_hash_folder(sub, hash);
 
-
 	/* Lookup anything before we lock anything, to avoid deadlock with build_folder */
 
 	/* Find newly added that match */
 	if (changes->uid_added->len > 0) {
+		CamelException ex = CAMEL_EXCEPTION_INITIALISER;
 		dd(printf(" Searching for added matches '%s'\n", vf->expression));
-		matches_added = camel_folder_search_by_uids(sub, vf->expression, changes->uid_added, NULL);
+		matches_added = camel_folder_search_by_uids(sub, vf->expression, changes->uid_added, &ex);
+		camel_exception_clear (&ex);
 	}
 
 	/* TODO:
@@ -1501,6 +1515,7 @@ folder_changed_change(CamelSession *session, CamelSessionThreadMsg *msg)
 	/* Search for changed items that newly match, but only if we dont have them */
 	changed = changes->uid_changed;
 	if (changed->len > 0) {
+		CamelException ex = CAMEL_EXCEPTION_INITIALISER;
 		dd(printf(" Searching for changed matches '%s'\n", vf->expression));
 
 		if ((vf->flags & CAMEL_STORE_VEE_FOLDER_AUTO) == 0) {
@@ -1526,10 +1541,11 @@ folder_changed_change(CamelSession *session, CamelSessionThreadMsg *msg)
 		}
 
 		if (changed->len)
-			matches_changed = camel_folder_search_by_uids(sub, vf->expression, changed, NULL);
+			matches_changed = camel_folder_search_by_uids(sub, vf->expression, changed, &ex);
+		camel_exception_clear (&ex);
 		if (always_changed && always_changed->len)
-			present = camel_folder_search_by_uids(sub, vf->expression, always_changed, NULL);
-
+			present = camel_folder_search_by_uids(sub, vf->expression, always_changed, &ex);
+		camel_exception_clear (&ex);
 	}
 
 	CAMEL_VEE_FOLDER_LOCK(vf, summary_lock);
@@ -1540,7 +1556,6 @@ folder_changed_change(CamelSession *session, CamelSessionThreadMsg *msg)
 	if (matches_changed || matches_added || changes->uid_removed->len||present)
 		camel_db_begin_transaction (folder->parent_store->cdb_w, NULL);
 
-
 	dd(printf("Vfolder '%s' subfolder changed '%s'\n", folder->full_name, sub->full_name));
 	dd(printf(" changed %u added %u removed %u\n", changes->uid_changed->len, changes->uid_added->len, changes->uid_removed->len));
 
@@ -1912,7 +1927,11 @@ vee_thaw(CamelFolder *folder)
 static void
 vee_add_folder(CamelVeeFolder *vf, CamelFolder *sub)
 {
-	vee_rebuild_folder(vf, sub, NULL);
+	CamelException ex = CAMEL_EXCEPTION_INITIALISER;
+
+	vee_rebuild_folder (vf, sub, &ex);
+
+	camel_exception_clear (&ex);
 }
 
 static void
@@ -1935,6 +1954,7 @@ vee_set_expression(CamelVeeFolder *vf, const gchar *query)
 {
 	struct _CamelVeeFolderPrivate *p = _PRIVATE(vf);
 	GList *node;
+	CamelException ex = CAMEL_EXCEPTION_INITIALISER;
 
 	CAMEL_VEE_FOLDER_LOCK(vf, subfolder_lock);
 
@@ -1949,7 +1969,8 @@ vee_set_expression(CamelVeeFolder *vf, const gchar *query)
 	if (vf->expression) {
 		CamelFolderSummary *s = ((CamelFolder *)vf)->summary;
 		camel_folder_summary_clear (s);
-		camel_db_recreate_vfolder (((CamelFolder *) vf)->parent_store->cdb_w, ((CamelFolder *) vf)->full_name, NULL);
+		camel_db_recreate_vfolder (((CamelFolder *) vf)->parent_store->cdb_w, ((CamelFolder *) vf)->full_name, &ex);
+		camel_exception_clear (&ex);
 		s->junk_count = 0;
 		s->deleted_count = 0;
 		s->unread_count = 0;
@@ -1957,7 +1978,6 @@ vee_set_expression(CamelVeeFolder *vf, const gchar *query)
 		s->junk_not_deleted_count = 0;
 	}
 
-
 	g_free(vf->expression);
 	if (query)
 		vf->expression = g_strdup(query);
@@ -1966,12 +1986,16 @@ vee_set_expression(CamelVeeFolder *vf, const gchar *query)
 	while (node) {
 		CamelFolder *f = node->data;
 
-		if (camel_vee_folder_rebuild_folder(vf, f, NULL) == -1)
+		if (camel_vee_folder_rebuild_folder (vf, f, &ex) == -1)
 			break;
 
+		camel_exception_clear (&ex);
+
 		node = node->next;
 	}
 
+	camel_exception_clear (&ex);
+
 	CAMEL_VEE_FOLDER_LOCK(vf, changed_lock);
 	g_list_free(p->folders_changed);
 	p->folders_changed = NULL;
@@ -1990,7 +2014,6 @@ vf_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 	guint32 tag;
 	gint unread = -1, deleted = 0, junked = 0, visible = 0, count = -1, junked_not_deleted = -1;
 
-
 	for (i=0;i<args->argc;i++) {
 		CamelArgGet *arg = &args->argv[i];
 
@@ -2158,7 +2181,6 @@ camel_vee_folder_unmask_event_folder_changed (CamelVeeFolder *vf, CamelFolder *s
 	camel_object_hook_event((CamelObject *)sub, "folder_changed", (CamelObjectEventHookFunc) folder_changed, vf);
 }
 
-
 static void
 vee_folder_stop_folder(CamelVeeFolder *vf, CamelFolder *sub)
 {
@@ -2177,7 +2199,6 @@ vee_folder_stop_folder(CamelVeeFolder *vf, CamelFolder *sub)
 		return;
 	}
 
-
 	camel_object_unhook_event((CamelObject *)sub, "folder_changed", (CamelObjectEventHookFunc) folder_changed, vf);
 	camel_object_unhook_event((CamelObject *)sub, "deleted", (CamelObjectEventHookFunc) subfolder_deleted, vf);
 	camel_object_unhook_event((CamelObject *)sub, "renamed", (CamelObjectEventHookFunc) folder_renamed, vf);
@@ -2258,9 +2279,11 @@ camel_vee_folder_finalise (CamelObject *obj)
 
 	/* Save the counts to DB */
 	if (!vf->deleted) {
+		CamelException ex = CAMEL_EXCEPTION_INITIALISER;
 		record = summary_header_to_db (((CamelFolder *)vf)->summary, NULL);
-		camel_db_write_folder_info_record (((CamelFolder *) vf)->parent_store->cdb_w, record, NULL);
+		camel_db_write_folder_info_record (((CamelFolder *) vf)->parent_store->cdb_w, record, &ex);
 		g_free (record);
+		camel_exception_clear (&ex);
 	}
 
 	/* This may invoke sub-classes with partially destroyed state, they must deal with this */
