@@ -60,14 +60,14 @@ static void do_multipart (EGwConnection *cnc, EGwItem *item, CamelMultipart *mp,
  *
  * Return value: the expanded path
  **/
-char *
-e_path_to_physical (const char *prefix, const char *vpath)
+gchar *
+e_path_to_physical (const gchar *prefix, const gchar *vpath)
 {
-	const char *p, *newp;
-	char *dp;
-	char *ppath;
-	int ppath_len;
-	int prefix_len;
+	const gchar *p, *newp;
+	gchar *dp;
+	gchar *ppath;
+	gint ppath_len;
+	gint prefix_len;
 
 	while (*vpath == '/')
 		vpath++;
@@ -110,7 +110,7 @@ e_path_to_physical (const char *prefix, const char *vpath)
 
 	/* Copy the mangled path.  */
 	p = vpath;
- 	while (1) {
+	while (1) {
 		newp = strchr (p, '/');
 		if (newp == NULL) {
 			strcpy (dp, p);
@@ -135,13 +135,12 @@ e_path_to_physical (const char *prefix, const char *vpath)
 	return ppath;
 }
 
-
 static gboolean
-find_folders_recursive (const char *physical_path, const char *path,
+find_folders_recursive (const gchar *physical_path, const gchar *path,
 			EPathFindFoldersCallback callback, gpointer data)
 {
 	GDir *dir;
-	char *subfolder_directory_path;
+	gchar *subfolder_directory_path;
 	gboolean ok;
 
 	if (*path) {
@@ -167,9 +166,9 @@ find_folders_recursive (const char *physical_path, const char *path,
 	ok = TRUE;
 	while (ok) {
 		struct stat file_stat;
-		const char *dirent;
-		char *file_path;
-		char *new_path;
+		const gchar *dirent;
+		gchar *file_path;
+		gchar *new_path;
 
 		dirent = g_dir_read_name (dir);
 		if (dirent == NULL)
@@ -209,14 +208,13 @@ find_folders_recursive (const char *physical_path, const char *path,
  * Return value: %TRUE on success, %FALSE if an error occurs at any point
  **/
 gboolean
-e_path_find_folders (const char *prefix,
+e_path_find_folders (const gchar *prefix,
 		     EPathFindFoldersCallback callback,
 		     gpointer data)
 {
 	return find_folders_recursive (prefix, "", callback, data);
 }
 
-
 /**
  * e_path_rmdir:
  * @prefix: a prefix to prepend to the path, or %NULL
@@ -230,10 +228,10 @@ e_path_find_folders (const char *prefix,
  * specified directory. 0 otherwise, whether or not it removed
  * the parent directory.
  **/
-int
-e_path_rmdir (const char *prefix, const char *vpath)
+gint
+e_path_rmdir (const gchar *prefix, const gchar *vpath)
 {
-	char *physical_path, *p;
+	gchar *physical_path, *p;
 
 	/* Remove the directory itself */
 	physical_path = e_path_to_physical (prefix, vpath);
@@ -264,15 +262,15 @@ e_path_rmdir (const char *prefix, const char *vpath)
 }
 
 static GSList *
-add_recipients(GSList *recipient_list, CamelAddress *recipients, int recipient_type)
+add_recipients(GSList *recipient_list, CamelAddress *recipients, gint recipient_type)
 {
-	int total_add,i;
+	gint total_add,i;
 	EGwItemRecipient *recipient;
-	
+
 	total_add = camel_address_length (recipients);
-	for (i=0 ; i<total_add ; i++) {
-		const char *name = NULL, *addr = NULL;
-		if(camel_internet_address_get ((CamelInternetAddress *)recipients, i , &name, &addr )) {
+	for (i=0; i<total_add; i++) {
+		const gchar *name = NULL, *addr = NULL;
+		if (camel_internet_address_get ((CamelInternetAddress *)recipients, i , &name, &addr )) {
 
 			recipient = g_new0 (EGwItemRecipient, 1);
 
@@ -287,7 +285,7 @@ add_recipients(GSList *recipient_list, CamelAddress *recipients, int recipient_t
 }
 
 static void
-send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content, CamelContentType *type, CamelDataWrapper *dw, const char *filename, const char *cid, GSList **attach_list)
+send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content, CamelContentType *type, CamelDataWrapper *dw, const gchar *filename, const gchar *cid, GSList **attach_list)
 {
 	EGwItemLinkInfo *info = NULL;
 	EGwConnectionStatus status;
@@ -302,8 +300,8 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 
 	if (filename && content->buffer->data) {
 		if (camel_content_type_is (type, "application", "pgp-signature")) {
-			char *temp_str;
-			int temp_len;
+			gchar *temp_str;
+			gint temp_len;
 			temp_str = g_base64_encode (content->buffer->data, content->buffer->len);
 			temp_len = strlen (temp_str);
 			attachment->data = g_strdup (temp_str);
@@ -316,8 +314,8 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 			attachment->size = strlen (attachment->data);
 		}
 	} else if (content->buffer->data) {
-		char *temp_str;
-		int temp_len;
+		gchar *temp_str;
+		gint temp_len;
 		if (!strcmp (attachment->contentType, "multipart/digest")) {
 			/* FIXME? */
 		} else {
@@ -330,7 +328,7 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 			temp_len = 0;
 		}
 	}
-	
+
 	if (camel_content_type_is (type, "text", "html") || camel_content_type_is (type, "multipart", "alternative")) {
 		if (!filename)
 			filename = "text.htm";
@@ -343,28 +341,27 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 
 	attachment->name = g_strdup (filename ? filename : "");
 	if (camel_content_type_is (type, "message", "rfc822")) {
-		const char *message_id;
-		char *msgid;
-		int len;
-		
-		message_id = camel_medium_get_header (CAMEL_MEDIUM (dw), "Message-Id");
+		gchar *item_id;
+
+		item_id = g_strdup (camel_medium_get_header (CAMEL_MEDIUM (dw), "X-GW-ITEM-ID"));
 		/*
 		 * XXX: The following code piece is a screwed up way of doing stuff.
 		 * But we dont have much choice. Do not use 'camel_header_msgid_decode'
 		 * since it removes the container id portion from the id and which the
 		 * groupwise server needs.
 		 */
-		
-		len = strlen (message_id);
-		msgid = (char *)g_malloc0 (len-1);
-		msgid = memcpy(msgid, message_id+2, len-3);
-		g_print ("||| msgid:%s\n", msgid);
+		g_strstrip (item_id);
+		status = e_gw_connection_forward_item (cnc, item_id, NULL, TRUE, &temp_item);
+		g_free (item_id);
 
-		status = e_gw_connection_forward_item (cnc, msgid, NULL, TRUE, &temp_item);
-		g_free (msgid);
-		
 		if (status != E_GW_CONNECTION_STATUS_OK) {
 			g_warning ("Could not send a forwardRequest...continuing without!!\n");
+
+			g_free (attachment->name);
+			attachment->name = g_strdup ("Mime.822");
+
+			g_free (attachment->contentType);
+			attachment->contentType = g_strdup ("Mail");
 		} else {
 			GSList *attach_list = e_gw_item_get_attach_id_list (temp_item);
 			EGwItemAttachment *temp_attach = (EGwItemAttachment *)attach_list->data;
@@ -374,7 +371,7 @@ send_as_attachment (EGwConnection *cnc, EGwItem *item, CamelStreamMem *content,
 			attachment->name = g_strdup (temp_attach->name);
 			g_free (attachment->contentType);
 			attachment->contentType = g_strdup ("Mail");
-			g_free (attachment->data); 
+			g_free (attachment->data);
 			attachment->data = NULL;
 			attachment->size = 0;
 			info = e_gw_item_get_link_info (temp_item);
@@ -390,29 +387,29 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 {
 	EGwItem *item;
 	EGwItemOrganizer *org = g_new0 (EGwItemOrganizer, 1);
-	const char *display_name = NULL, *email = NULL;
-	char *send_options = NULL;
+	const gchar *display_name = NULL, *email = NULL;
+	gchar *send_options = NULL;
 	CamelMultipart *mp;
 	GSList *recipient_list = NULL, *attach_list = NULL;
 	CamelAddress *recipients;
 
 	/*Egroupwise item*/
 	item = e_gw_item_new_empty ();
-	
+
 	/*populate recipient list*/
 	recipients = CAMEL_ADDRESS (camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_TO));
 	recipient_list=add_recipients(recipient_list,recipients,E_GW_ITEM_RECIPIENT_TO);
-	
+
 	recipients = CAMEL_ADDRESS (camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_CC));
 	recipient_list=add_recipients(recipient_list,recipients,E_GW_ITEM_RECIPIENT_CC);
-	
+
 	recipients = CAMEL_ADDRESS (camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_BCC));
 	recipient_list=add_recipients(recipient_list,recipients,E_GW_ITEM_RECIPIENT_BC);
 	recipient_list = g_slist_reverse (recipient_list);
-	
+
 	/** Get the mime parts from CamelMimemessge **/
 	mp = (CamelMultipart *)camel_medium_get_content_object (CAMEL_MEDIUM (message));
-	if(!mp) {
+	if (!mp) {
 		g_warning ("ERROR: Could not get content object");
 		camel_operation_end (NULL);
 		return NULL;
@@ -426,20 +423,20 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 		CamelStreamMem *content = (CamelStreamMem *)camel_stream_mem_new ();
 		CamelDataWrapper *dw = NULL;
 		CamelContentType *type;
-		
+
 		dw = camel_medium_get_content_object (CAMEL_MEDIUM (message));
 		type = camel_mime_part_get_content_type((CamelMimePart *)message);
-		
+
 		if (camel_content_type_is (type, "text", "plain")) {
 			CamelStream *filtered_stream;
 			CamelMimeFilter *filter;
-			const char *charset;
-			char *content_type;
-			
+			const gchar *charset;
+			gchar *content_type;
+
 			content_type = camel_content_type_simple (type);
 			e_gw_item_set_content_type (item, content_type);
 			g_free (content_type);
-			
+
 			charset = camel_content_type_param (type, "charset");
 			if (charset && g_ascii_strcasecmp (charset, "US-ASCII") && g_ascii_strcasecmp (charset, "UTF-8")) {
 				filter = (CamelMimeFilter *) camel_mime_filter_charset_new_convert (charset, "UTF-8");
@@ -451,18 +448,18 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 				filtered_stream = (CamelStream *) content;
 				camel_object_ref (content);
 			}
-			
+
 			camel_data_wrapper_decode_to_stream (dw, filtered_stream);
 			camel_stream_flush (filtered_stream);
 			camel_object_unref (filtered_stream);
-			
+
 			camel_stream_write ((CamelStream *) content, "", 1);
-			e_gw_item_set_message (item, (const char *)content->buffer->data);
+			e_gw_item_set_message (item, (const gchar *)content->buffer->data);
 		} else {
 			camel_data_wrapper_decode_to_stream (dw, (CamelStream *) content);
-			send_as_attachment (cnc, item, content, type, dw, NULL, NULL, &attach_list);	
+			send_as_attachment (cnc, item, content, type, dw, NULL, NULL, &attach_list);
 		}
-		
+
 		camel_object_unref (content);
 	}
 	/*Populate EGwItem*/
@@ -479,29 +476,29 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 	e_gw_item_set_subject (item, camel_mime_message_get_subject(message));
 	/*attachmets*/
 	e_gw_item_set_attach_id_list (item, attach_list);
-	
+
 	/*send options*/
 	e_gw_item_set_sendoptions (item, TRUE);
 
-	if ((char *)camel_medium_get_header (CAMEL_MEDIUM(message), X_REPLY_CONVENIENT)) 
+	if ((gchar *)camel_medium_get_header (CAMEL_MEDIUM(message), X_REPLY_CONVENIENT))
 		e_gw_item_set_reply_request (item, TRUE);
-	
-	send_options = (char *)camel_medium_get_header (CAMEL_MEDIUM(message), X_REPLY_WITHIN);
-	if (send_options) { 
+
+	send_options = (gchar *)camel_medium_get_header (CAMEL_MEDIUM(message), X_REPLY_WITHIN);
+	if (send_options) {
 		e_gw_item_set_reply_request (item, TRUE);
 		e_gw_item_set_reply_within (item, send_options);
 	}
-	send_options = (char *)camel_medium_get_header (CAMEL_MEDIUM(message),X_EXPIRE_AFTER);
+	send_options = (gchar *)camel_medium_get_header (CAMEL_MEDIUM(message),X_EXPIRE_AFTER);
 	if (send_options)
 		e_gw_item_set_expires (item, send_options);
 
-	send_options = (char *)camel_medium_get_header (CAMEL_MEDIUM(message), X_DELAY_UNTIL);
+	send_options = (gchar *)camel_medium_get_header (CAMEL_MEDIUM(message), X_DELAY_UNTIL);
 	if (send_options)
 		e_gw_item_set_delay_until (item, send_options);
 
-	send_options = (char *)camel_medium_get_header (CAMEL_MEDIUM(message), X_TRACK_WHEN);
+	send_options = (gchar *)camel_medium_get_header (CAMEL_MEDIUM(message), X_TRACK_WHEN);
 
-	/*we check if user has modified the status tracking options, if no then we anyway 
+	/*we check if user has modified the status tracking options, if no then we anyway
 	 * set status tracking all*/
 	if (send_options) {
 		switch (atoi(send_options)) {
@@ -517,10 +514,10 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 	} else
 		e_gw_item_set_track_info (item, E_GW_ITEM_ALL);
 
-	if ((char *)camel_medium_get_header (CAMEL_MEDIUM(message), X_AUTODELETE))
+	if ((gchar *)camel_medium_get_header (CAMEL_MEDIUM(message), X_AUTODELETE))
 		e_gw_item_set_autodelete (item, TRUE);
 
-	send_options = (char *)camel_medium_get_header (CAMEL_MEDIUM (message), X_RETURN_NOTIFY_OPEN);
+	send_options = (gchar *)camel_medium_get_header (CAMEL_MEDIUM (message), X_RETURN_NOTIFY_OPEN);
 	if (send_options) {
 		switch (atoi(send_options)) {
 			case 0: e_gw_item_set_notify_opened (item, E_GW_ITEM_NOTIFY_NONE);
@@ -528,16 +525,16 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 			case 1: e_gw_item_set_notify_opened (item, E_GW_ITEM_NOTIFY_MAIL);
 		}
 	}
-	send_options = (char *)camel_medium_get_header (CAMEL_MEDIUM (message), X_RETURN_NOTIFY_DELETE);
+	send_options = (gchar *)camel_medium_get_header (CAMEL_MEDIUM (message), X_RETURN_NOTIFY_DELETE);
 	if (send_options) {
 		switch (atoi(send_options)) {
 			case 0: e_gw_item_set_notify_deleted (item, E_GW_ITEM_NOTIFY_NONE);
 				break;
 			case 1: e_gw_item_set_notify_deleted (item, E_GW_ITEM_NOTIFY_MAIL);
 		}
-	}	
-	
-	send_options = (char *)camel_medium_get_header (CAMEL_MEDIUM (message), X_SEND_OPT_PRIORITY);
+	}
+
+	send_options = (gchar *)camel_medium_get_header (CAMEL_MEDIUM (message), X_SEND_OPT_PRIORITY);
 	if (send_options) {
 		switch (atoi(send_options)) {
 			case E_GW_PRIORITY_HIGH: e_gw_item_set_priority(item, "High");
@@ -549,7 +546,7 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 		}
 	}
 
-	send_options = (char *)camel_medium_get_header (CAMEL_MEDIUM (message), X_SEND_OPT_SECURITY);
+	send_options = (gchar *)camel_medium_get_header (CAMEL_MEDIUM (message), X_SEND_OPT_SECURITY);
 	if (send_options) {
 		switch (atoi(send_options)) {
 			case E_GW_SECURITY_NORMAL : e_gw_item_set_security(item, "Normal");
@@ -565,7 +562,7 @@ camel_groupwise_util_item_from_message (EGwConnection *cnc, CamelMimeMessage *me
 			case E_GW_SECURITY_FOR_YOUR_EYES_ONLY : e_gw_item_set_security(item, "ForYourEyesOnly");
 								break;
 		}
-	} 
+	}
 	return item;
 }
 
@@ -576,10 +573,10 @@ do_flags_diff (flags_diff_t *diff, guint32 old, guint32 _new)
 	diff->bits = _new & diff->changed;
 }
 
-char *
-gw_concat ( const char *prefix, const char *suffix)
+gchar *
+gw_concat ( const gchar *prefix, const gchar *suffix)
 {
-	size_t len;
+	gsize len;
 
 	len = strlen (prefix);
 	if (len == 0 || prefix[len - 1] == '/')
@@ -589,15 +586,15 @@ gw_concat ( const char *prefix, const char *suffix)
 }
 
 void
-strip_lt_gt (char **string, int s_offset, int e_offset)
+strip_lt_gt (gchar **string, gint s_offset, gint e_offset)
 {
-	char *temp = NULL;
-	int len;
-	
+	gchar *temp = NULL;
+	gint len;
+
 	temp = g_strdup (*string);
 	len = strlen (*string);
 
-	*string = (char *)g_malloc0 (len-1);
+	*string = (gchar *)g_malloc0 (len-1);
 	*string = memcpy(*string, temp+s_offset, len-e_offset);
 	g_free (temp);
 }
@@ -607,16 +604,16 @@ do_multipart (EGwConnection *cnc, EGwItem *item, CamelMultipart *mp, GSList **at
 {
 	/*contains multiple parts*/
 	guint part_count;
-	int i;
+	gint i;
 
 	part_count = camel_multipart_get_number (mp);
-	for ( i=0 ; i<part_count ; i++) {
+	for ( i=0; i<part_count; i++) {
 		CamelContentType *type;
 		CamelMimePart *part;
 		CamelStreamMem *content = (CamelStreamMem *)camel_stream_mem_new ();
 		CamelDataWrapper *dw = NULL;
-		const char *disposition, *filename;
-		const char *content_id = NULL;
+		const gchar *disposition, *filename;
+		const gchar *content_id = NULL;
 		gboolean is_alternative = FALSE;
 		/*
 		 * XXX:
@@ -630,19 +627,19 @@ do_multipart (EGwConnection *cnc, EGwItem *item, CamelMultipart *mp, GSList **at
 
 		type = camel_mime_part_get_content_type(part);
 		dw = camel_medium_get_content_object (CAMEL_MEDIUM (part));
-		
+
 		if (CAMEL_IS_MULTIPART (dw)) {
 			do_multipart (cnc, item, (CamelMultipart *) camel_medium_get_content_object ((CamelMedium *) part), attach_list);
 			continue;
 		}
-		
+
 		if (type->subtype && !strcmp (type->subtype, "alternative")) {
 			/* eh... I don't think this code will ever get hit? */
 			CamelMimePart *temp_part;
-			const char *cid = NULL;
+			const gchar *cid = NULL;
 			CamelStreamMem *temp_content = (CamelStreamMem *)camel_stream_mem_new ();
 			CamelDataWrapper *temp_dw = NULL;
-			
+
 			temp_part = camel_multipart_get_part ((CamelMultipart *)dw, 1);
 			if (temp_part) {
 				is_alternative = TRUE;
@@ -655,18 +652,18 @@ do_multipart (EGwConnection *cnc, EGwItem *item, CamelMultipart *mp, GSList **at
 			}
 			camel_object_unref (temp_content);
 			continue;
-		} 
-		
+		}
+
 		if (i == 0 && camel_content_type_is (type, "text", "plain")) {
 			CamelStream *filtered_stream;
 			CamelMimeFilter *filter;
-			const char *charset;
-			char *content_type;
-			
+			const gchar *charset;
+			gchar *content_type;
+
 			content_type = camel_content_type_simple (type);
 			e_gw_item_set_content_type (item, content_type);
 			g_free (content_type);
-			
+
 			charset = camel_content_type_param (type, "charset");
 			if (charset && g_ascii_strcasecmp (charset, "US-ASCII") && g_ascii_strcasecmp (charset, "UTF-8")) {
 				filter = (CamelMimeFilter *) camel_mime_filter_charset_new_convert (charset, "UTF-8");
@@ -678,22 +675,22 @@ do_multipart (EGwConnection *cnc, EGwItem *item, CamelMultipart *mp, GSList **at
 				filtered_stream = (CamelStream *) content;
 				camel_object_ref (content);
 			}
-			
+
 			camel_data_wrapper_decode_to_stream (dw, filtered_stream);
 			camel_stream_flush (filtered_stream);
 			camel_object_unref (filtered_stream);
-			
+
 			camel_stream_write ((CamelStream *) content, "", 1);
-			e_gw_item_set_message (item, (const char *)content->buffer->data);
+			e_gw_item_set_message (item, (const gchar *)content->buffer->data);
 		} else {
 			filename = camel_mime_part_get_filename (part);
 			disposition = camel_mime_part_get_disposition (part);
 			content_id = camel_mime_part_get_content_id (part);
-			
+
 			camel_data_wrapper_decode_to_stream (dw, (CamelStream *) content);
 			send_as_attachment (cnc, item, content, type, dw, filename, content_id, attach_list);
 		}
-		
+
 		camel_object_unref (content);
 	} /*end of for*/
 }
