@@ -164,6 +164,19 @@ static CamelLocalSummary *maildir_create_summary(CamelLocalFolder *lf, const gch
 	return (CamelLocalSummary *)camel_maildir_summary_new((CamelFolder *)lf, path, folder, index);
 }
 
+
+static gboolean
+skip_summary_check (void)
+{
+	const char *skip = g_getenv ("SKIP_LSUMMARY_CHECK");
+
+	if (skip) 
+		return TRUE;
+	else
+		return FALSE;	
+	
+}
+
 static void
 maildir_append_message (CamelFolder *folder, CamelMimeMessage *message, const CamelMessageInfo *info, gchar **appended_uid, CamelException *ex)
 {
@@ -179,6 +192,9 @@ maildir_append_message (CamelFolder *folder, CamelMimeMessage *message, const Ca
 	if (camel_local_folder_lock (lf, CAMEL_LOCK_WRITE, ex) == -1)
 		return;
 
+	if (!skip_summary_check () && camel_local_summary_check ((CamelLocalSummary*) folder->summary, lf->changes, ex) == -1)
+		goto check_changed;
+
 	/* add it to the summary/assign the uid, etc */
 	mi = camel_local_summary_add((CamelLocalSummary *)folder->summary, message, info, lf->changes, ex);
 	if (camel_exception_is_set (ex))
@@ -284,6 +300,9 @@ maildir_get_message(CamelFolder * folder, const gchar * uid, CamelException * ex
 	if (camel_local_folder_lock (lf, CAMEL_LOCK_WRITE, ex) == -1)
 		return NULL;
 
+	if (!skip_summary_check () && camel_local_summary_check ((CamelLocalSummary*) folder->summary, lf->changes, ex) == -1)
+		goto fail;
+
 	/* get the message summary info */
 	if ((info = camel_folder_summary_uid(folder->summary, uid)) == NULL) {
 		camel_exception_setv(ex, CAMEL_EXCEPTION_FOLDER_INVALID_UID,
