@@ -79,7 +79,7 @@ static gboolean     e_tree_model_generator_iter_parent     (GtkTreeModel       *
 							    GtkTreeIter        *child);
 
 static GArray *build_node_map     (ETreeModelGenerator *tree_model_generator, GtkTreeIter *parent_iter,
-			           GArray *parent_group, gint parent_index);
+				   GArray *parent_group, gint parent_index);
 static void    release_node_map   (GArray *group);
 
 static void    child_row_changed  (ETreeModelGenerator *tree_model_generator, GtkTreePath *path, GtkTreeIter *iter);
@@ -648,12 +648,12 @@ child_row_changed (ETreeModelGenerator *tree_model_generator, GtkTreePath *path,
 		gtk_tree_path_next (generated_path);
 	}
 
-	for ( ; i < node->n_generated; ) {
+	for (; i < node->n_generated; ) {
 		node->n_generated--;
 		row_deleted (tree_model_generator, generated_path);
 	}
 
-	for ( ; i < n_generated; i++) {
+	for (; i < n_generated; i++) {
 		node->n_generated++;
 		row_inserted (tree_model_generator, generated_path);
 		gtk_tree_path_next (generated_path);
@@ -707,7 +707,7 @@ child_row_deleted (ETreeModelGenerator *tree_model_generator, GtkTreePath *path)
 
 	/* FIXME: Converting the path to an iter every time is inefficient */
 
-	for ( ; node->n_generated; ) {
+	for (; node->n_generated; ) {
 		node->n_generated--;
 		row_deleted (tree_model_generator, generated_path);
 	}
@@ -770,7 +770,7 @@ e_tree_model_generator_get_model (ETreeModelGenerator *tree_model_generator)
 void
 e_tree_model_generator_set_generate_func (ETreeModelGenerator *tree_model_generator,
 					  ETreeModelGeneratorGenerateFunc func,
-					  gpointer data, GtkDestroyNotify destroy)
+					  gpointer data, GDestroyNotify destroy)
 {
 	g_return_if_fail (E_IS_TREE_MODEL_GENERATOR (tree_model_generator));
 
@@ -793,7 +793,7 @@ e_tree_model_generator_set_generate_func (ETreeModelGenerator *tree_model_genera
 void
 e_tree_model_generator_set_modify_func (ETreeModelGenerator *tree_model_generator,
 					ETreeModelGeneratorModifyFunc func,
-					gpointer data, GtkDestroyNotify destroy)
+					gpointer data, GDestroyNotify destroy)
 {
 	g_return_if_fail (E_IS_TREE_MODEL_GENERATOR (tree_model_generator));
 
@@ -959,7 +959,7 @@ e_tree_model_generator_convert_iter_to_child_iter (ETreeModelGenerator *tree_mod
 	GArray      *group;
 	gint         generator_index;
 	gint         index;
-	gint         internal_offset;
+	gint         internal_offset = 0;
 
 	g_return_if_fail (E_IS_TREE_MODEL_GENERATOR (tree_model_generator));
 	g_return_if_fail (ITER_IS_VALID (tree_model_generator, generator_iter));
@@ -1109,7 +1109,7 @@ e_tree_model_generator_iter_next (GtkTreeModel  *tree_model,
 	GArray              *group;
 	gint                 index;
 	gint                 child_index;
-	gint                 internal_offset;
+	gint                 internal_offset = 0;
 
 	g_return_val_if_fail (E_IS_TREE_MODEL_GENERATOR (tree_model), FALSE);
 	g_return_val_if_fail (ITER_IS_VALID (tree_model_generator, iter), FALSE);
